.redirect_form_row.field_error label{color:#dc3232}.redirect_form_row.field_error input{border-color:#dc3232}tbody .column-old div:after{color:#d3d3d3;content:"/"}tbody .column-new .has-trailing-slash:after,tbody .column-new div:before,tbody .column-old div:before{content:"/"}tbody .column-new .remove-slashes:after,tbody .column-new .remove-slashes:before,tbody .column-old .remove-slashes:after,tbody .column-old .remove-slashes:before{content:none}.wpseo-redirect-clear{clear:both}